import React, {
  useState,
  useCallback,
  useEffect,
} from 'react';
import ReactDOM from 'react-dom';
import { csv, arc, pie } from 'd3';

const csvUrl =
  'https://gist.githubusercontent.com/curran/b236990081a24761f7000567094914e0/raw/cssNamedColors.csv';
const width = 960;
const height = 540;
const centerWidth = width / 2;
const centerHeight = height / 2;
const pieArc = arc();

const App = () => {
  const [data, setData] = useState(null);

  useEffect(() => {
    csv(csvUrl).then(setData);
  }, []);

  if (!data) {
    return <pre>Loading...</pre>;
  }
  //
  return (
    <svg width={width} height={height}>
      {data.map((d, i) => (
        <g
          transform={`translate(${centerWidth},${centerHeight})`}
        >
          <path
            fill={d['RGB hex value']}
            d={pieArc({
              innerRadius: 0,
              outerRadius: 10*(i%25),
              startAngle:
                (i / data.length) * 2 * Math.PI,
              endAngle:
                ((i + 1) / data.length) *
                2 *
                Math.PI,
            })}
          />
        </g>
      ))}
    </svg>
  );
};
const rootElement = document.getElementById(
  'root'
);
ReactDOM.render(<App />, rootElement);
